begin — begins 0.8 documentation

begins 0.8 documentation
modules | index

# Source code for begin

    "Convenience function for starting Python programs"
    from __future__ import absolute_import, division, print_function
    from begin.context import context
    from begin.convert import convert
    from begin.main import start
    from begin.subcommands import subcommand
    from begin.version import __version__

    from begin.extensions import tracebacks
    from begin.extensions import logger as logging

    import begin.formatters
    import begin.utils

    __all__ = ['start']